pub struct CasefoldStr(/* private fields */);Expand description
A borrowed slice of a casefolded string.
It is designed to be the borrowed counterpart to CasefoldString, mirroring
the relationship between str and String.
We wrap str instead of a struct like CasefoldStr<'a>(&'a str)
so that CasefoldString can implement Deref<Target = CasefoldStr>. This allows
CasefoldString to coerce to &CasefoldStr automatically, and enables zero-allocation
map lookups via Borrow<CasefoldStr>.
Implementations